import { createMuiTheme, withStyles, createStyles } from '@material-ui/core/styles';
import React from 'react';
import { SvgIcon, makeStyles, Box, Typography, createStyles as createStyles$1 } from '@material-ui/core';
import ExpandMore from '@material-ui/icons/ExpandMore';
import NotificationsIcon from '@material-ui/icons/Notifications';
import ErrorIcon from '@material-ui/icons/Error';
import CheckCircleIcon from '@material-ui/icons/CheckCircle';
import MuiBadge from '@material-ui/core/Badge';
import MuiBreadcrumbs from '@material-ui/core/Breadcrumbs';
import MuiTabs from '@material-ui/core/Tabs';
import { Error } from '@material-ui/icons';
import Link from '@material-ui/core/Link';
import Paper from '@material-ui/core/Paper';
import Typography$1 from '@material-ui/core/Typography';

/**
 * Theme-level overrides for the MuiBadge component.
 */
const badgeThemeOverrides = (theme) => ({
    badge: {
        // This will need to be overriden for badges displayed on a dark background.
        border: `2px solid ${theme.palette.background.paper}`,
        padding: '0 4px',
        fontSize: `${11 / 16}rem`,
    },
    colorPrimary: {
        color: theme.palette.primary.dark,
        backgroundColor: theme.palette.primary.light,
    },
    colorSecondary: {
        color: theme.palette.secondary.dark,
        backgroundColor: theme.palette.secondary.light,
    },
    colorError: {
        color: theme.palette.error.dark,
        backgroundColor: theme.palette.error.light,
    },
});
const badgeDefaultProps = {
    // There is no "default" style for badges, only primary, secondary, error.
    color: 'primary',
};

/**
 * Theme-level overrides for the Muiradio component.
 */
const radioThemeOverrides = (theme) => ({
    root: {
        color: theme.palette.divider,
        '& .MuiSvgIcon-root': {
            fontSize: `${26 / 16}rem`,
            fill: theme.palette.background.paper,
            stroke: 'currentColor',
            transition: 'color 200ms ease',
        },
        '&:hover': {
            color: theme.custom.bluePastel,
        },
        '&.Mui-focusVisible': {
            color: theme.custom.bluePastel,
        },
    },
    colorPrimary: {
        '&$checked': {
            color: theme.palette.action.selected,
        },
    },
});
const radioDefaultProps = {
    // We only want to support one style for radios.
    color: 'primary',
    icon: (React.createElement(SvgIcon, { viewBox: "0 0 26 26" },
        React.createElement("circle", { strokeWidth: "2", cx: "13", cy: "13", r: "12" }))),
    checkedIcon: (React.createElement(SvgIcon, { viewBox: "0 0 26 26" },
        React.createElement("circle", { strokeWidth: "6", cx: "13", cy: "13", r: "10" }))),
};

/**
 * Theme-level overrides for the MuiSelect component.
 */
const selectThemeOverrides = (theme) => ({
    root: {
        '& ~ .MuiOutlinedInput-notchedOutline': {
            boxShadow: theme.custom.boxShadow.DEFAULT,
        },
        '.Mui-disabled & ~ .MuiOutlinedInput-notchedOutline': {
            boxShadow: 'none',
        },
    },
    iconOutlined: {
        right: theme.spacing(2),
        '.Mui-disabled &': {
            color: theme.palette.text.secondary,
        },
        '.Mui-error &': {
            color: theme.custom.redPastel,
        },
    },
});
const selectDefaultProps = {
    // Make all selects native by default.
    native: true,
    // Use the outlined variant by default.
    variant: 'outlined',
    IconComponent: ExpandMore,
};

/**
 * Theme-level overrides for the MuiCheckbox component.
 */
const checkboxThemeOverrides = (theme) => ({
    root: {
        color: theme.palette.text.disabled,
        '& .MuiSvgIcon-root': {
            fontSize: `${26 / 16}rem`,
        },
        '&$disabled': {
            color: theme.palette.text.disabled,
            '& .MuiSvgIcon-root': {
                color: theme.palette.text.disabled,
            },
        },
        '&:hover': {
            color: theme.custom.bluePastel,
        },
        '&.Mui-focusVisible': {
            color: theme.custom.bluePastel,
        },
    },
    colorPrimary: {
        '&$checked': {
            color: theme.palette.action.active,
        },
        '&$disabled': {
            color: theme.palette.text.disabled,
        },
    },
});
const checkboxDefaultProps = {
    color: 'primary',
    checkedIcon: (React.createElement(SvgIcon, { viewBox: "0 0 26 26" },
        React.createElement("rect", { fill: "currentColor", width: "26", height: "26", rx: "3" }),
        React.createElement("path", { fill: "#FFF", d: "M10.808 19L5.05 13.242l1.623-1.624 4.135 4.123L19.548 7l1.625 1.635z" }))),
    icon: (React.createElement(SvgIcon, { viewBox: "0 0 26 26" },
        React.createElement("rect", { stroke: "currentColor", fill: "#FFF", strokeWidth: "2", x: "1", y: "1", width: "24", height: "24", rx: "3" }))),
};

/**
 * Theme-level overrides for the MuiLink component.
 */
const linkThemeOverrides = (theme) => ({
    root: {
        transition: 'color 200ms ease',
        '&.MuiTypography-colorPrimary:hover': {
            color: theme.custom.redMid,
        },
        '&.MuiTypography-colorSecondary': {
            color: theme.custom.yellowPastel,
            '&:hover': {
                color: theme.palette.primary.light,
            },
        },
    },
});
const linkDefaultProps = {
    // Links should have no underline, unless they are inline in text.
    underline: 'none',
};

const textFieldDefaultProps = {
    // Use the outlined variant by default.
    variant: 'outlined',
};

/**
 * Theme-level overrides for the MuiBreadcrumbs component.
 */
const breadcrumbThemeOverrides = (theme) => ({
    separator: {
        color: theme.palette.divider,
        margin: theme.spacing(0, 3),
        fontWeight: 800,
    },
});

/**
 * Theme-level overrides for the MuiAlert component.
 */
const alertThemeOverrides = (theme) => ({
    root: {
        padding: theme.spacing(3),
        alignItems: `center`,
        flexWrap: `wrap`,
        position: `relative`,
        [theme.breakpoints.up('md')]: {
            padding: theme.spacing(3),
        },
        [theme.breakpoints.up('lg')]: {
            height: `50px`,
            padding: theme.spacing(0, 3),
            borderRadius: 0,
        },
        '& .MuiAlertTitle-root': {
            color: theme.palette.primary.dark,
            fontWeight: theme.typography.fontWeightBold,
            fontSize: 13,
            display: `block`,
            marginTop: 0,
            marginBottom: theme.spacing(2),
            [theme.breakpoints.up('md')]: {
                display: `inline-block`,
                fontSize: 14,
                marginRight: theme.spacing(2),
            },
        },
    },
    message: {
        ...theme.typography.caption,
        color: 'inherit',
        display: `block`,
        [theme.breakpoints.up('md')]: {
            display: `flex`,
            flex: `1 0 60%`,
            '& .MuiTypography-gutterBottom': {
                marginBottom: 0,
            },
        },
    },
    icon: {
        padding: theme.spacing(1, 0),
        [theme.breakpoints.down('md')]: {
            display: `none`,
        },
    },
    action: {
        marginRight: 0,
        paddingLeft: 0,
        '& .MuiAlert-cta': {
            fontFamily: theme.typography.fontFamily,
            fontSize: 14,
            textTransform: `uppercase`,
            fontWeight: theme.typography.fontWeightBold,
            marginRight: 0,
            letterSpacing: `0.6px`,
            '&:hover': {
                backgroundColor: 'initial',
            },
        },
        '& .MuiAlert-close': {
            minWidth: `auto`,
            borderRadius: 0,
            '&:hover': {
                backgroundColor: 'initial',
            },
        },
        [theme.breakpoints.down('md')]: {
            flex: `1 0 100%`,
            display: `block`,
            '& .MuiAlert-cta': {
                padding: theme.spacing(0, 2, 0, 0),
                marginLeft: theme.spacing(-1),
            },
            '& .MuiAlert-close': {
                position: `absolute`,
                right: theme.spacing(1),
                top: theme.spacing(1),
            },
        },
        [theme.breakpoints.up('lg')]: {
            '& .MuiAlert-cta': {
                paddingRight: theme.spacing(3),
            },
            '& .MuiAlert-close': {
                borderLeft: `2px solid rgba(1, 31, 91, 0.1)`,
                marginLeft: theme.spacing(1),
                paddingLeft: theme.spacing(2),
            },
        },
    },
    standardInfo: {
        backgroundColor: theme.palette.primary.light,
        color: theme.palette.primary.dark,
        '& $icon': {
            color: theme.palette.primary.dark,
        },
    },
    standardWarning: {
        backgroundColor: theme.palette.secondary.light,
        color: theme.palette.primary.dark,
        '& $icon': {
            color: theme.palette.primary.dark,
        },
    },
    standardError: {
        backgroundColor: theme.palette.error.light,
        color: theme.palette.primary.dark,
        '& $icon': {
            color: theme.palette.error.dark,
        },
    },
    standardSuccess: {
        backgroundColor: theme.palette.primary.light,
        color: theme.palette.primary.dark,
        '& $icon': {
            color: theme.palette.primary.dark,
        },
    },
});
const alertDefaultProps = {
    severity: 'info',
    iconMapping: {
        info: React.createElement(NotificationsIcon, null),
        warning: React.createElement(NotificationsIcon, null),
        error: React.createElement(ErrorIcon, null),
        success: React.createElement(CheckCircleIcon, null),
    },
};

/**
 * Theme-level overrides for the MuiTooltip component.
 */
const tooltipThemeOverrides = (theme) => ({
    popper: {
        maxWidth: 260,
        margin: theme.spacing(0, 2),
    },
    tooltip: {
        ...theme.typography.caption,
        'background-color': theme.palette.primary.dark,
        color: theme.palette.primary.light,
        padding: theme.spacing(2),
        textAlign: 'center',
    },
    arrow: {
        color: theme.palette.primary.dark,
    },
});
const tooltipDefaultProps = {
    arrow: true,
    placement: 'top',
};

/**
 * Theme-level global overrides for form-related components.
 * Restrict usage of this file’s styles to only components that are related to forms.
 */
const formsThemeOverrides = (theme) => ({
    MuiFormControlLabel: {
        root: {
            // spacing between horizontal checkbox & radio form elements
            marginRight: theme.spacing(6),
        },
    },
    MuiFormHelperText: {
        root: {
            fontSize: `${13 / 16}rem !important`,
            textAlign: `right`,
        },
    },
    MuiOutlinedInput: {
        root: {
            'label + &': {
                marginTop: theme.spacing(1.5),
            },
        },
        input: {
            fontSize: theme.typography.fontSize,
            paddingLeft: 15,
            paddingTop: 12,
            paddingBottom: 12,
            '$root.Mui-focused &': {
                backgroundColor: theme.palette.background.paper,
            },
            '&:disabled': {
                color: theme.palette.text.secondary,
                backgroundColor: theme.palette.divider,
            },
        },
        notchedOutline: {
            borderWidth: 2,
            borderColor: theme.palette.divider,
            borderRadius: 3,
            transition: 'border-color .20s ease',
            '$root.Mui-error &': {
                borderColor: theme.custom.redPastel,
            },
            '$input:hover ~ &, $input:active ~ &, $root.Mui-focused &': {
                borderColor: theme.custom.bluePastel,
                borderRadius: 3,
            },
            '$root.Mui-disabled &': {
                borderColor: theme.palette.divider,
            },
        },
        adornedEnd: {
            paddingRight: theme.spacing(2),
        },
    },
    MuiInputLabel: {
        root: {
            ...theme.typography.h5,
            '&.Mui-focused, &.Mui-error': {
                color: theme.palette.primary.dark,
            },
        },
        outlined: {
            '&, &$shrink': {
                transform: 'none',
            },
        },
        formControl: {
            position: `relative`,
            '&.Mui-disabled': {
                color: theme.palette.text.secondary,
                zIndex: 2,
            },
        },
        shrink: {
            transform: 'none',
        },
    },
    MuiFormGroup: {
        root: {
            marginTop: theme.spacing(1),
        },
    },
    MuiFormLabel: {
        root: {
            ...theme.typography.h5,
            '&.Mui-focused, &.Mui-error': {
                color: theme.palette.primary.dark,
            },
        },
    },
    MuiInputAdornment: {
        root: {
            '.Mui-error &': {
                color: theme.custom.redPastel,
            },
        },
    },
});
const formsDefaultProps = {
    MuiInputLabel: {
        // Disable Material UI floating labels by default.
        shrink: true,
    },
    MuiInput: {
        // Disable underlines for all fields, since ours have borders.
        disableUnderline: true,
    },
    MuiOutlinedInput: {
        // Disable notch for all outlined inputs.
        notched: false,
    },
    MuiFormHelperText: {
        variant: 'standard',
    },
    MuiInputAdornment: {
        // Focus the input on click.
        disablePointerEvents: true,
    },
};

/**
 * Theme-level overrides for the MuiPagination component.
 */
const paginationThemeOverrides = (theme) => ({
    root: {
        '& .MuiPaginationItem-outlined': {
            border: `2px solid ${theme.custom.greyPastel}`,
            transition: 'border .20s ease',
            margin: `0 ${theme.spacing(1.3)}px`,
            '&:hover, &.Mui-selected': {
                'background-color': 'white',
                border: `2px solid ${theme.custom.bluePastel}`,
            },
        },
    },
});
const paginationDefaultProps = {
    variant: 'outlined',
    shape: 'rounded',
};

/**
 * Theme-level overrides for the MuiBadge component.
 */
const tableThemeOverrides = (theme) => ({
    root: {
        border: `2px solid ${theme.custom.greyLight}`,
        padding: 0,
        overflow: `visible`,
        position: `relative`,
        '& .MuiTableCell-head': {
            ...theme.typography.subtitle1,
            '& .MuiSvgIcon-root': {
                verticalAlign: `middle`,
            },
        },
        '& .MuiTableRow-root': {
            '&:hover': {
                boxShadow: `2px 2px 10px 0px rgba(0,0,0,0.08)`,
            },
        },
        '& .MuiTableCell-root': {
            borderBottom: `2px solid ${theme.custom.greyLight}`,
            padding: theme.spacing(6),
        },
    },
});
const tableContainerThemeOverrides = (theme) => ({
    root: {
        '&::after': {
            content: `''`,
            display: `block`,
            position: `absolute`,
            background: `linear-gradient(90deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0.5032387955182073) 50%, rgba(255,255,255,1) 100%)`,
            right: 0,
            top: 0,
            width: 60,
            height: `100%`,
            pointerEvents: `none`,
            [theme.breakpoints.up('sm')]: {
                display: `none`,
            },
        },
    },
});

/**
 * Theme-level overrides for the MuiTabs component.
 */
const tabsThemeOverrides = (theme) => ({
    root: {
        fontWeight: theme.typography.fontWeightBold,
        boxShadow: `none`,
        padding: theme.spacing(0, 3, 0, 0),
        marginBottom: theme.spacing(6),
        position: `relative`,
        [theme.breakpoints.up('sm')]: {
            marginBottom: theme.spacing(10),
        },
        '&::after': {
            content: `''`,
            display: `block`,
            position: `absolute`,
            background: `linear-gradient(90deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0.5032387955182073) 50%, rgba(255,255,255,1) 100%)`,
            right: 0,
            top: 0,
            width: 60,
            height: 50,
            pointerEvents: `none`,
            [theme.breakpoints.up('sm')]: {
                display: 'none',
            },
        },
        '& .MuiTab-root': {
            ...theme.typography.subtitle1,
            letterSpacing: 0.6,
            opacity: 0.5,
            margin: theme.spacing(0, 3),
            minWidth: 50,
            padding: 0,
            borderBottom: `3px solid transparent`,
            transition: `opacity .20s ease, border-bottom-color .20s ease`,
            [theme.breakpoints.up('sm')]: {
                fontSize: `${14 / 16}rem`,
            },
            '&.Mui-selected': {
                opacity: 1,
            },
            '&:hover, &:focus': {
                borderBottomColor: theme.custom.bluePastel,
            },
            '&:first-child': {
                marginLeft: 0,
            },
            '&:last-child': {
                marginRight: 0,
            },
        },
    },
    scroller: {
        flexGrow: 0,
        borderBottom: `1px solid ${theme.palette.divider}`,
    },
    indicator: {
        height: 3,
        backgroundColor: theme.custom.bluePastel,
    },
});
const tabsDefaultProps = {
    indicatorColor: 'primary',
    textColor: 'primary',
    variant: 'scrollable',
    selectionFollowsFocus: true,
};

/**
 * Theme-level overrides for the MuiButton component.
 */
const buttonThemeOverrides = (theme) => ({
    root: {
        borderRadius: 3,
        textTransform: 'uppercase',
        letterSpacing: 0.8,
        fontSize: theme.typography.body1.fontSize,
        fontWeight: theme.typography.fontWeightBold,
        fontFamily: 'inherit',
        height: 44,
        paddingRight: theme.spacing(4),
        paddingLeft: theme.spacing(2),
        '&.Mui-focusVisible, &$contained.Mui-focusVisible': {
            boxShadow: theme.custom.boxShadow.focus,
        },
        '& svg': {
            width: '1.5rem',
            height: '1.5rem',
        },
    },
    startIcon: {
        color: theme.custom.bluePastel,
    },
    disableElevation: {
        '&:active': {
            boxShadow: theme.custom.boxShadow.pressed,
        },
    },
    contained: {
        boxShadow: 'none',
        '&:hover': {
            boxShadow: 'none',
        },
        '&$disabled': {
            backgroundColor: theme.palette.action.disabledBackground,
            color: theme.custom.greyPastel,
        },
    },
    containedPrimary: {
        backgroundColor: theme.palette.primary.dark,
        color: theme.palette.primary.contrastText,
        '&:hover': {
            backgroundColor: theme.palette.primary.main,
        },
    },
    containedSecondary: {
        backgroundColor: theme.palette.primary.contrastText,
        color: theme.palette.primary.dark,
        '&:hover': {
            backgroundColor: theme.palette.primary.light,
        },
    },
    outlined: {
        '&:active': {
            boxShadow: theme.custom.boxShadow.pressed,
        },
        '&:hover $startIcon': {
            color: 'currentColor',
        },
        '&$disabled': {
            borderWidth: 2,
            borderColor: 'currentColor',
            color: theme.palette.action.disabledBackground,
        },
    },
    outlinedPrimary: {
        color: theme.palette.primary.dark,
        borderWidth: 2,
        borderColor: 'currentColor',
        '&:hover': {
            color: theme.palette.primary.main,
            borderWidth: 2,
            borderColor: 'currentColor',
        },
    },
    outlinedSecondary: {
        color: theme.palette.primary.contrastText,
        borderWidth: 2,
        borderColor: 'currentColor',
        '&:hover': {
            color: theme.palette.primary.light,
            borderWidth: 2,
            borderColor: 'currentColor',
        },
        '&$disabled': {
            borderWidth: 2,
            borderColor: 'currentColor',
        },
    },
    disabled: {
        '& $startIcon': {
            color: 'currentColor',
        },
    },
    containedSizeSmall: {
        height: 32,
    },
    outlinedSizeSmall: {
        height: 32,
    },
});
const buttonDefaultProps = {
    // Main style meant to be used.
    variant: 'contained',
    color: 'primary',
};

/**
 * Theme-level overrides for the MuiChip component.
 */
const chipThemeOverrides = (theme) => ({
    root: {
        textTransform: 'uppercase',
        // fontSize: theme.typography.caption.fontSize,
        fontSize: `${11 / 16}rem`,
        fontWeight: theme.typography.fontWeightBold,
        backgroundColor: theme.palette.error.light,
        color: theme.palette.error.dark,
        transition: 'color 0.2s ease, background-color 0.2s ease',
        height: 22,
    },
    clickable: {
        '&:hover': {
            cursor: 'pointer',
            backgroundColor: theme.palette.error.dark,
            color: theme.palette.error.light,
        },
    },
    colorPrimary: {
        backgroundColor: theme.palette.info.light,
        color: theme.palette.info.dark,
    },
    clickableColorPrimary: {
        '&:hover': {
            backgroundColor: theme.palette.info.dark,
            color: theme.palette.info.light,
        },
    },
    colorSecondary: {
        backgroundColor: theme.palette.warning.light,
        color: theme.palette.warning.dark,
    },
    clickableColorSecondary: {
        '&:hover': {
            backgroundColor: theme.palette.warning.dark,
            color: theme.palette.warning.light,
        },
    },
});

/** @typedef {string} ColorHex */
/** @typedef {string} ColorJS */
/** @typedef {string} ColorCSS */

/** @typedef {{
    hex: ColorHex;
    js: ColorJS;
    css: ColorCSS;
    bgUtility: ColorCSS;
    textUtility: ColorCSS;
    usage: string;
    contrastText: keyof typeof allColors;
}} Shade */

/** @typedef {{
    [jsName: string]: Shade;
}} Color */

/** @type {Color} */
const grey = {
    greyDark: {
        hex: '#222222',
        js: 'greyDark',
        css: 'grey-dark',
        bgUtility: 'bg-grey-dark',
        textUtility: 'text-grey-dark',
        usage: 'Body text',
        contrastText: 'white',
    },
    greyMid: {
        hex: '#707070',
        js: 'greyMid',
        css: 'grey-mid',
        bgUtility: 'bg-grey-mid',
        textUtility: 'text-grey-mid',
        usage: 'Meta text',
        contrastText: 'white',
    },
    greyPastel: {
        hex: '#dde0ed',
        js: 'greyPastel',
        css: 'grey-pastel',
        bgUtility: 'bg-grey-pastel',
        textUtility: 'text-grey-pastel',
        usage: 'Dividers, Field borders',
        contrastText: 'blueDark',
    },
    greyLight: {
        hex: '#f2f4fa',
        js: 'greyLight',
        css: 'grey-light',
        bgUtility: 'bg-grey-light',
        textUtility: 'text-grey-light',
        usage: 'Page backgrounds, Panels',
        contrastText: 'blueDark',
    },
    white: {
        hex: '#ffffff',
        js: 'white',
        css: 'white',
        bgUtility: 'bg-white',
        textUtility: 'text-white',
        usage: 'Page backgrounds, Panels, Button text',
        contrastText: 'blueDark',
    },
};

const blue$1 = {
    blueDark: {
        hex: '#011f5b',
        js: 'blueDark',
        css: 'blue-dark',
        bgUtility: 'bg-blue-dark',
        textUtility: 'text-blue-dark',
        usage: 'Penn branding, Panels, Headings, Buttons, Labels',
        contrastText: 'white',
    },
    blueMid: {
        hex: '#0c66b8',
        js: 'blueMid',
        css: 'blue-mid',
        bgUtility: 'bg-blue-mid',
        textUtility: 'text-blue-mid',
        usage: 'Text links, Hover states (buttons, tag/chips)',
        contrastText: 'white',
    },
    bluePastel: {
        hex: '#82afd3',
        js: 'bluePastel',
        css: 'blue-pastel',
        bgUtility: 'bg-blue-pastel',
        textUtility: 'text-blue-pastel',
        usage: 'Field borders (hover, active states), Icons, Tabs',
        contrastText: 'blueDark',
    },
    blueLight: {
        hex: '#bddbf3',
        js: 'blueLight',
        css: 'blue-light',
        bgUtility: 'bg-blue-light',
        textUtility: 'text-blue-light',
        usage: 'Information Alerts, Tag/Chip, Badges',
        contrastText: 'blueDark',
    },
};

const red = {
    redDark: {
        hex: '#990000',
        js: 'redDark',
        css: 'red-dark',
        bgUtility: 'bg-red-dark',
        textUtility: 'text-red-dark',
        usage: 'Penn branding',
        contrastText: 'redLight',
    },
    redMid: {
        hex: '#cd3535',
        js: 'redMid',
        css: 'red-mid',
        bgUtility: 'bg-red-mid',
        textUtility: 'text-red-mid',
        usage: 'Hover states (text, buttons, tag/chip)',
        contrastText: 'white',
    },
    redPastel: {
        hex: '#ff6767',
        js: 'redPastel',
        css: 'red-pastel',
        bgUtility: 'bg-red-pastel',
        textUtility: 'text-red-pastel',
        usage: 'Field borders (error state), Icons',
        contrastText: 'blueDark',
    },
    redLight: {
        hex: '#ffadad',
        js: 'redLight',
        css: 'red-light',
        bgUtility: 'bg-red-light',
        textUtility: 'text-red-light',
        usage: 'Emergency/Error Alerts, Tag/Chip, Badges',
        contrastText: 'redDark',
    },
};

const yellow = {
    yellowDark: {
        hex: '#836900',
        js: 'yellowDark',
        css: 'yellow-dark',
        bgUtility: 'bg-yellow-dark',
        textUtility: 'text-yellow-dark',
        usage: 'Hover states (tag/chip)',
        contrastText: 'yellowLight',
    },
    yellowMid: {
        hex: '#f2c100',
        js: 'yellowMid',
        css: 'yellow-mid',
        bgUtility: 'bg-yellow-mid',
        textUtility: 'text-yellow-mid',
        usage: 'Success Alerts',
        contrastText: 'blueDark',
    },
    yellowPastel: {
        hex: '#ffe57d',
        js: 'yellowPastel',
        css: 'yellow-pastel',
        bgUtility: 'bg-yellow-pastel',
        textUtility: 'text-yellow-pastel',
        usage: 'Tag/Chips, Badges',
        contrastText: 'blueDark',
    },
    yellowLight: {
        hex: '#fff1b9',
        js: 'yellowLight',
        css: 'yellow-light',
        bgUtility: 'bg-yellow-light',
        textUtility: 'text-yellow-light',
        usage:
            'Warning Alerts, Tag/Chip, Badges, Text links (dark backgrounds)',
        contrastText: 'yellowDark',
    },
};

const utilities = {
    greyPastel75: {
        hex: '#e5e8f1',
        js: 'greyPastel75',
        css: 'grey-pastel-75',
        bgUtility: 'bg-grey-pastel-75',
        textUtility: 'text-grey-pastel-75',
        usage: 'Disabled fields',
        contrastText: 'blueDark',
    },
    blueDark50: {
        hex: '#7d8caa',
        js: 'blueDark50',
        css: 'blue-dark-50',
        bgUtility: 'bg-blue-dark-50',
        textUtility: 'text-blue-dark-50',
        usage: 'Disabled buttons',
        contrastText: 'white',
    },
};

const allColors = {
    ...grey,
    ...blue$1,
    ...red,
    ...yellow,
    ...utilities,
};

const colorRanges = {
    grey: {
        label: 'Grey',
        shades: grey,
        usage: 'Text, Backgrounds, Furniture',
    },
    blue: {
        label: 'Blue',
        shades: blue$1,
        usage: 'Backgrounds, Action, Information',
    },
    red: {
        label: 'Red',
        shades: red,
        usage: 'Emergency/Error, Destructive actions',
    },
    yellow: {
        label: 'Yellow',
        shades: yellow,
        usage: 'Warning, Highlights (on dark backgrounds)',
    },
    utilities: { label: 'Disabled states', shades: utilities, usage: '' },
};

var colors = {
    grey,
    blue: blue$1,
    red,
    yellow,
    utilities,
    allColors,
    colorRanges,
};

// See https://css-tricks.com/snippets/css/system-font-stack/#method-1-system-fonts-at-the-element-level.
const emojiFontStack = [
    'Apple Color Emoji',
    'Segoe UI Emoji',
    'Segoe UI Symbol',
    'Noto Color Emoji',
];

// Font stack optimised for built-in fonts of each major operating system, with support for emojis.
// Only displayed if the site’s web fonts fail to load.
// See https://polaris.shopify.com/design/typography#section-font-stack.
const fallbackSans = [
    '-apple-system',
    'BlinkMacSystemFont',
    'San Francisco',
    'Segoe UI',
    'Helvetica Neue',
    'sans-serif',
    ...emojiFontStack,
];

const fallbackSerif = [
    'Roboto',
    'Georgia',
    'Cambria',
    'serif',
    ...emojiFontStack,
];

const fontSans = ['Roboto', ...fallbackSans];

const fontSerif = ['EB Garamond', ...fallbackSerif];

const fontMono = ['SFMono-Regular', 'Menlo', 'monospace'];

const fontSize = {
    h1: { lg: 56, md: 44, sm: 32 },
    h2: { lg: 32, md: 28, sm: 24 },
    h3: { lg: 24, md: 22, sm: 20 },
    h4: { lg: 20, md: 18, sm: 16 },
    h5: { lg: 16, md: 15, sm: 14 },
    h6: { lg: 16, md: 15, sm: 14 },
    body: { lg: 16, md: 15, sm: 14 },
    meta: { lg: 14, md: 13, sm: 13 },
    label: { lg: 13, md: 12, sm: 12 },
    labellight: { lg: 13, md: 12, sm: 12 },
};

const fontWeight = {
    light: 300,
    normal: 400,
    medium: 500,
    semibold: 600,
    bold: 700,
};

const letterSpacing = {
    // tightest: '-2px',
    tighter: '-0.5px',
    tight: '-0.4px',
    normal: '0',
    // wide: '0.5px',
    wider: '1px',
    // widest: '2px',
};

var typography = {
    fontSans,
    fontSerif,
    fontMono,
    fontSize,
    fontWeight,
    letterSpacing,
};

/** @typedef {{
 xs: number;
 sm: number;
 md: number;
 lg: number;
 xl: number;
}} Breakpoints */
/** @type {Breakpoints} */
const breakpoints = {
    xs: 0,
    sm: 600,
    md: 768,
    lg: 1024,
    xl: 1280,
};

var breakpoints_1 = breakpoints;

const { blue } = colors;

const borderRadius = {
    none: '0',
    DEFAULT: '3px',
    full: '100%',
};

const boxShadow = {
    // Used for Select dropdown’s elevation.
    DEFAULT: '0 1px 2px 0 rgba(184, 184, 184, 0.24)',
    // Active state for a lot of UI components.
    pressed: 'inset 1px 1px 5px 0 rgba(1, 31, 91, 0.5)',
    focus: `0 0 3px 2px ${blue.bluePastel.hex}`,
    none: 'none',
};

const spacing = {
    1: '10px',
    2: '15px',
    3: '20px',
    4: '25px',
    5: '30px',
    6: '50px',
    7: '60px',
    10: '100px',
    20: '200px',
};

var other = {
    borderRadius,
    boxShadow,
    spacing,
};

const palette = {
    primary: {
        light: colors.blue.blueLight.hex,
        main: colors.blue.blueMid.hex,
        dark: colors.blue.blueDark.hex,
        contrastText: colors.allColors[colors.blue.blueDark.contrastText].hex,
    },
    secondary: {
        light: colors.yellow.yellowLight.hex,
        main: colors.yellow.yellowMid.hex,
        dark: colors.yellow.yellowDark.hex,
        contrastText: colors.allColors[colors.yellow.yellowDark.contrastText]
            .hex,
    },
    error: {
        light: colors.red.redLight.hex,
        main: colors.red.redMid.hex,
        dark: colors.red.redDark.hex,
        contrastText: '',
    },
    warning: {
        light: colors.yellow.yellowLight.hex,
        main: colors.yellow.yellowLight.hex,
        dark: colors.yellow.yellowDark.hex,
        contrastText: '',
    },
    info: {
        light: colors.blue.blueLight.hex,
        main: colors.blue.blueLight.hex,
        dark: colors.blue.blueDark.hex,
        contrastText: '',
    },
    success: {
        light: colors.blue.blueLight.hex,
        main: colors.blue.blueLight.hex,
        dark: colors.blue.blueDark.hex,
        contrastText: '',
    },
    text: {
        primary: colors.grey.greyDark.hex,
        secondary: colors.grey.greyMid.hex,
        disabled: colors.utilities.greyPastel75.hex,
        hint: colors.grey.greyMid.hex,
    },
    action: {
        active: colors.blue.bluePastel.hex,
        hover: colors.blue.blueMid.hex,
        selected: colors.blue.bluePastel.hex,
        disabled: colors.grey.white.hex,
        disabledBackground: colors.utilities.blueDark50.hex,
    },
    background: {
        default: colors.grey.white.hex,
        paper: colors.grey.white.hex,
    },
    divider: colors.grey.greyPastel.hex,
};
const custom = {
    pennRed: colors.red.redDark.hex,
    redMid: colors.red.redMid.hex,
    yellowMid: colors.yellow.yellowMid.hex,
    bluePastel: colors.blue.bluePastel.hex,
    yellowPastel: colors.yellow.yellowPastel.hex,
    redPastel: colors.red.redPastel.hex,
    greyPastel: colors.grey.greyPastel.hex,
    blueDark50: colors.utilities.blueDark50.hex,
    greyLight: colors.grey.greyLight.hex,
    boxShadow: { ...other.boxShadow },
};
const theme = createMuiTheme({
    spacing: 5,
    breakpoints: {
        values: {
            ...breakpoints_1,
        },
    },
    palette,
}, { custom });
const baseFontSize = 16;
const setThemeFontSize = (t, style) => ({
    fontSize: `${typography.fontSize[style].sm / baseFontSize}rem`,
    [t.breakpoints.up('md')]: {
        fontSize: `${typography.fontSize[style].md / baseFontSize}rem`,
    },
    [t.breakpoints.up('lg')]: {
        fontSize: `${typography.fontSize[style].lg / baseFontSize}rem`,
    },
});
const setFontSize = setThemeFontSize.bind(null, theme);
const sans = typography.fontSans.join(', ');
const serif = typography.fontSerif.join(', ');
theme.typography = {
    fontFamily: sans,
    fontSize: baseFontSize,
    fontWeightLight: typography.fontWeight.light,
    fontWeightRegular: typography.fontWeight.normal,
    fontWeightMedium: typography.fontWeight.medium,
    fontWeightBold: typography.fontWeight.bold,
    h1: {
        fontFamily: serif,
        fontWeight: typography.fontWeight.semibold,
        ...setFontSize('h1'),
        letterSpacing: typography.letterSpacing.tighter,
        color: palette.primary.dark,
    },
    h2: {
        fontFamily: serif,
        fontWeight: typography.fontWeight.semibold,
        ...setFontSize('h2'),
        letterSpacing: typography.letterSpacing.tight,
        color: palette.primary.dark,
    },
    h3: {
        fontFamily: serif,
        fontWeight: typography.fontWeight.semibold,
        ...setFontSize('h3'),
        letterSpacing: typography.letterSpacing.tight,
        color: palette.primary.dark,
    },
    h4: {
        fontFamily: serif,
        fontWeight: typography.fontWeight.semibold,
        ...setFontSize('h4'),
        color: palette.primary.dark,
    },
    h5: {
        fontFamily: sans,
        fontWeight: typography.fontWeight.medium,
        ...setFontSize('h5'),
        color: palette.primary.dark,
    },
    h6: {
        fontFamily: sans,
        fontWeight: typography.fontWeight.medium,
        ...setFontSize('h6'),
        color: palette.primary.dark,
    },
    body1: {
        fontFamily: sans,
        ...setFontSize('body'),
        color: palette.text.primary,
    },
    body2: {
        fontFamily: sans,
        ...setFontSize('body'),
        color: palette.text.primary,
    },
    button: {},
    overline: {},
    caption: {
        fontFamily: sans,
        ...setFontSize('meta'),
        color: palette.text.secondary,
    },
    subtitle1: {
        fontFamily: sans,
        fontWeight: typography.fontWeight.bold,
        ...setFontSize('label'),
        letterSpacing: typography.letterSpacing.wider,
        color: palette.primary.dark,
        textTransform: 'uppercase',
    },
    subtitle2: {
        fontFamily: sans,
        ...setFontSize('labellight'),
        letterSpacing: typography.letterSpacing.wider,
        color: palette.primary.dark,
        textTransform: 'uppercase',
    },
    pxToRem: theme.typography.pxToRem,
};
theme.overrides = {
    ...formsThemeOverrides(theme),
    MuiIconButton: {
        root: {
            '&:hover': {
                backgroundColor: 'transparent !important',
            },
        },
    },
    MuiLink: linkThemeOverrides(theme),
    MuiBadge: badgeThemeOverrides(theme),
    MuiSelect: selectThemeOverrides(theme),
    MuiRadio: radioThemeOverrides(theme),
    MuiCheckbox: checkboxThemeOverrides(theme),
    MuiBreadcrumbs: breadcrumbThemeOverrides(theme),
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore See https://github.com/mui-org/material-ui/issues/19427.
    MuiAlert: alertThemeOverrides(theme),
    MuiTooltip: tooltipThemeOverrides(theme),
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore See https://github.com/mui-org/material-ui/issues/19427.
    MuiPagination: paginationThemeOverrides(theme),
    MuiTable: tableThemeOverrides(theme),
    MuiTableContainer: tableContainerThemeOverrides(theme),
    MuiTabs: tabsThemeOverrides(theme),
    MuiButton: buttonThemeOverrides(theme),
    MuiChip: chipThemeOverrides(theme),
};
theme.props = {
    ...formsDefaultProps,
    MuiButtonBase: {
        // No more ripple, on the whole application 💣!
        disableRipple: true,
    },
    MuiLink: linkDefaultProps,
    MuiBadge: badgeDefaultProps,
    MuiRadio: radioDefaultProps,
    MuiSelect: selectDefaultProps,
    MuiCheckbox: checkboxDefaultProps,
    MuiTextField: textFieldDefaultProps,
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore See https://github.com/mui-org/material-ui/issues/19427.
    MuiAlert: alertDefaultProps,
    MuiTooltip: tooltipDefaultProps,
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore See https://github.com/mui-org/material-ui/issues/19427.
    MuiPagination: paginationDefaultProps,
    MuiTabs: tabsDefaultProps,
    MuiButton: buttonDefaultProps,
};

// Prop types overriden to only allow BadgeProps.
// See https://jira.apps.upenn.edu/jira/browse/NGSSUI-396.
/**
 * Alternative to the Badge component, when displayed over a dark background.
 */
const DarkBadge = withStyles((theme) => createStyles({
    badge: {
        borderColor: theme.palette.primary.dark,
    },
}))(MuiBadge);

/**
 * Alternative to the standard Breadcrumb component, when displayed on a dark background.
 */
const DarkBreadcrumbs = withStyles((theme) => createStyles({
    li: {
        color: theme.custom.greyPastel,
        '& .MuiLink-root': {
            color: 'inherit',
        },
    },
    separator: {
        color: `rgba(255,255,255, 0.5)`,
    },
}))(MuiBreadcrumbs);

/**
 * Alternative to the Tabs component, when displayed over a dark background.
 */
const DarkTabs = withStyles((theme) => createStyles({
    root: {
        borderBottom: 0,
        '&::after': {
            background: `linear-gradient(90deg, rgba(1,31,91,0) 0%, rgba(1,31,91,0.5032387955182073) 50%, rgba(1,31,91,1) 100%)`,
        },
        '& .MuiTab-root': {
            color: theme.palette.background.default,
        },
    },
    scroller: {
        borderBottom: 0,
    },
    indicator: {
        backgroundColor: theme.custom.yellowMid,
    },
}))(MuiTabs);

const useStyles$1 = makeStyles((theme) => ({
    root: {
        textAlign: 'center',
        lineHeight: 1.5,
    },
    icon: {
        color: theme.custom.greyPastel,
        height: 75,
        width: 75,
        '$dark &': {
            color: theme.custom.blueDark50,
        },
        [theme.breakpoints.up('sm')]: {
            height: 175,
            width: 175,
            marginBottom: theme.spacing(1),
        },
    },
    dark: {
        color: theme.custom.greyPastel,
        '& .MuiTypography-h1': {
            color: theme.palette.primary.contrastText,
        },
    },
}));
const EmptyState = ({ heading, label, variant = 'light', }) => {
    const isDark = variant === 'dark';
    const classes = useStyles$1();
    return (React.createElement(Box, { className: `${classes.root} ${isDark ? classes.dark : ''}` },
        React.createElement(Error, { className: classes.icon }),
        React.createElement(Typography, { variant: "h1", variantMapping: { h1: 'p' }, color: "inherit" }, heading),
        label ? (React.createElement(Typography, { variant: "body1", color: "inherit" }, label)) : null));
};

/**
 *  The UPenn shield logo in dark blue.
 */
const Shield = ({ width, height }) => {
    return (React.createElement("svg", { width: width, height: height, viewBox: "0 0 54 54", "aria-hidden": "true" },
        React.createElement("g", { fillRule: "evenodd" },
            React.createElement("path", { d: "M14.479 43.412c5.325 4.987 11.259 7.554 12.555 7.594 1.3-.04 7.266-2.62 12.605-7.634L27.084 31.068 14.479 43.412z", fill: "#FFF" }),
            React.createElement("path", { d: "M5.412 24.21c0 3.77.886 7.154 2.3 10.145l19.372-17.542L46.41 34.262c1.39-2.968 2.258-6.32 2.258-10.052v-8.432H5.412v8.432z", fill: "#FFF" }),
            React.createElement("path", { d: "M3.667 15.778h46v-15h-46z" }),
            React.createElement("path", { d: "M48.667 15.778v8.432c0 3.732-.869 7.084-2.258 10.051l-19.325-17.57L7.712 34.354c-1.414-2.99-2.3-6.373-2.3-10.144V2.588h43.255v13.19zM27.034 51.007c-1.296-.041-7.23-2.608-12.555-7.595l12.605-12.343 12.555 12.303c-5.339 5.013-11.305 7.594-12.605 7.635zM3 0v24.034c0 19.51 21.3 29.7 24.033 29.786 2.735-.086 24.047-10.276 24.047-29.786V0H3z" }),
            React.createElement("path", { d: "M16.899 29.442a3.79 3.79 0 00-3.792 3.79 3.787 3.787 0 003.792 3.795 3.791 3.791 0 100-7.585M23.315 24.18a3.794 3.794 0 003.79 3.794c2.094 0 3.795-1.7 3.795-3.794a3.796 3.796 0 00-3.794-3.79 3.794 3.794 0 00-3.791 3.79M37.48 37.026a3.791 3.791 0 100-7.584 3.79 3.79 0 00-3.791 3.79 3.787 3.787 0 003.792 3.794", fill: "#FFF" }))));
};

const useStyles = makeStyles((theme) => createStyles$1({
    root: {
        display: 'block',
        width: 130,
        height: 130,
        borderTop: `3px solid ${theme.custom.bluePastel}`,
        transition: 'border-top-color .25s ease',
        '&:hover, &:active, &:focus': {
            borderColor: theme.custom.yellowMid,
            '& svg': {
                fill: theme.palette.primary.dark,
            },
            '& .MuiPaper-root': {
                boxShadow: '0px 3px 3px -2px rgba(0,0,0,0.2), 0px 3px 4px 0px rgba(0,0,0,0.14), 0px 1px 8px 0px rgba(0,0,0,0.12)',
            },
        },
        '& svg': {
            transition: 'fill .40s ease',
            width: 48,
            height: 48,
            fill: theme.custom.greyPastel,
        },
    },
    paper: {
        height: '100%',
        padding: theme.spacing(4, 2, 2),
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'center',
        justifyContent: 'space-between',
        borderTopLeftRadius: 0,
        borderTopRightRadius: 0,
        boxShadow: '0px 3px 3px -2px rgba(0,0,0,0.1), 0px 3px 4px 0px rgba(0,0,0,0.1), 0px 1px 8px 0px rgba(0,0,0,0.05)',
        transition: 'box-shadow .40s ease',
    },
    title: {
        color: theme.palette.primary.dark,
        fontWeight: theme.typography.fontWeightMedium,
        textAlign: 'center',
        fontSize: theme.typography.body1.fontSize,
    },
}));
/**
 * A component containing a logo and text that is used for linking to something or somewhere.
 * Titles are truncated to 30 chars.
 */
const Tile = ({ href, title }) => {
    const classes = useStyles();
    const truncated = title.length > 30 ? `${title.substring(0, 30)}…` : title;
    return (React.createElement(Link, { href: href, className: classes.root, title: title },
        React.createElement(Paper, { elevation: 3, className: classes.paper },
            React.createElement(Shield, null),
            React.createElement(Typography$1, { className: classes.title, "aria-hidden": "true" }, truncated))));
};

export { DarkBadge, DarkBreadcrumbs, DarkTabs, EmptyState, Shield, Tile, theme };
