'use strict';

/** @typedef {string} ColorHex */
/** @typedef {string} ColorJS */
/** @typedef {string} ColorCSS */

/** @typedef {{
    hex: ColorHex;
    js: ColorJS;
    css: ColorCSS;
    bgUtility: ColorCSS;
    textUtility: ColorCSS;
    usage: string;
    contrastText: keyof typeof allColors;
}} Shade */

/** @typedef {{
    [jsName: string]: Shade;
}} Color */

/** @type {Color} */
const grey = {
    greyDark: {
        hex: '#222222',
        js: 'greyDark',
        css: 'grey-dark',
        bgUtility: 'bg-grey-dark',
        textUtility: 'text-grey-dark',
        usage: 'Body text',
        contrastText: 'white',
    },
    greyMid: {
        hex: '#707070',
        js: 'greyMid',
        css: 'grey-mid',
        bgUtility: 'bg-grey-mid',
        textUtility: 'text-grey-mid',
        usage: 'Meta text',
        contrastText: 'white',
    },
    greyPastel: {
        hex: '#dde0ed',
        js: 'greyPastel',
        css: 'grey-pastel',
        bgUtility: 'bg-grey-pastel',
        textUtility: 'text-grey-pastel',
        usage: 'Dividers, Field borders',
        contrastText: 'blueDark',
    },
    greyLight: {
        hex: '#f2f4fa',
        js: 'greyLight',
        css: 'grey-light',
        bgUtility: 'bg-grey-light',
        textUtility: 'text-grey-light',
        usage: 'Page backgrounds, Panels',
        contrastText: 'blueDark',
    },
    white: {
        hex: '#ffffff',
        js: 'white',
        css: 'white',
        bgUtility: 'bg-white',
        textUtility: 'text-white',
        usage: 'Page backgrounds, Panels, Button text',
        contrastText: 'blueDark',
    },
};

const blue$1 = {
    blueDark: {
        hex: '#011f5b',
        js: 'blueDark',
        css: 'blue-dark',
        bgUtility: 'bg-blue-dark',
        textUtility: 'text-blue-dark',
        usage: 'Penn branding, Panels, Headings, Buttons, Labels',
        contrastText: 'white',
    },
    blueMid: {
        hex: '#0c66b8',
        js: 'blueMid',
        css: 'blue-mid',
        bgUtility: 'bg-blue-mid',
        textUtility: 'text-blue-mid',
        usage: 'Text links, Hover states (buttons, tag/chips)',
        contrastText: 'white',
    },
    bluePastel: {
        hex: '#82afd3',
        js: 'bluePastel',
        css: 'blue-pastel',
        bgUtility: 'bg-blue-pastel',
        textUtility: 'text-blue-pastel',
        usage: 'Field borders (hover, active states), Icons, Tabs',
        contrastText: 'blueDark',
    },
    blueLight: {
        hex: '#bddbf3',
        js: 'blueLight',
        css: 'blue-light',
        bgUtility: 'bg-blue-light',
        textUtility: 'text-blue-light',
        usage: 'Information Alerts, Tag/Chip, Badges',
        contrastText: 'blueDark',
    },
};

const red = {
    redDark: {
        hex: '#990000',
        js: 'redDark',
        css: 'red-dark',
        bgUtility: 'bg-red-dark',
        textUtility: 'text-red-dark',
        usage: 'Penn branding',
        contrastText: 'redLight',
    },
    redMid: {
        hex: '#cd3535',
        js: 'redMid',
        css: 'red-mid',
        bgUtility: 'bg-red-mid',
        textUtility: 'text-red-mid',
        usage: 'Hover states (text, buttons, tag/chip)',
        contrastText: 'white',
    },
    redPastel: {
        hex: '#ff6767',
        js: 'redPastel',
        css: 'red-pastel',
        bgUtility: 'bg-red-pastel',
        textUtility: 'text-red-pastel',
        usage: 'Field borders (error state), Icons',
        contrastText: 'blueDark',
    },
    redLight: {
        hex: '#ffadad',
        js: 'redLight',
        css: 'red-light',
        bgUtility: 'bg-red-light',
        textUtility: 'text-red-light',
        usage: 'Emergency/Error Alerts, Tag/Chip, Badges',
        contrastText: 'redDark',
    },
};

const yellow = {
    yellowDark: {
        hex: '#836900',
        js: 'yellowDark',
        css: 'yellow-dark',
        bgUtility: 'bg-yellow-dark',
        textUtility: 'text-yellow-dark',
        usage: 'Hover states (tag/chip)',
        contrastText: 'yellowLight',
    },
    yellowMid: {
        hex: '#f2c100',
        js: 'yellowMid',
        css: 'yellow-mid',
        bgUtility: 'bg-yellow-mid',
        textUtility: 'text-yellow-mid',
        usage: 'Success Alerts',
        contrastText: 'blueDark',
    },
    yellowPastel: {
        hex: '#ffe57d',
        js: 'yellowPastel',
        css: 'yellow-pastel',
        bgUtility: 'bg-yellow-pastel',
        textUtility: 'text-yellow-pastel',
        usage: 'Tag/Chips, Badges',
        contrastText: 'blueDark',
    },
    yellowLight: {
        hex: '#fff1b9',
        js: 'yellowLight',
        css: 'yellow-light',
        bgUtility: 'bg-yellow-light',
        textUtility: 'text-yellow-light',
        usage:
            'Warning Alerts, Tag/Chip, Badges, Text links (dark backgrounds)',
        contrastText: 'yellowDark',
    },
};

const utilities = {
    greyPastel75: {
        hex: '#e5e8f1',
        js: 'greyPastel75',
        css: 'grey-pastel-75',
        bgUtility: 'bg-grey-pastel-75',
        textUtility: 'text-grey-pastel-75',
        usage: 'Disabled fields',
        contrastText: 'blueDark',
    },
    blueDark50: {
        hex: '#7d8caa',
        js: 'blueDark50',
        css: 'blue-dark-50',
        bgUtility: 'bg-blue-dark-50',
        textUtility: 'text-blue-dark-50',
        usage: 'Disabled buttons',
        contrastText: 'white',
    },
};

const allColors$1 = {
    ...grey,
    ...blue$1,
    ...red,
    ...yellow,
    ...utilities,
};

const colorRanges = {
    grey: {
        label: 'Grey',
        shades: grey,
        usage: 'Text, Backgrounds, Furniture',
    },
    blue: {
        label: 'Blue',
        shades: blue$1,
        usage: 'Backgrounds, Action, Information',
    },
    red: {
        label: 'Red',
        shades: red,
        usage: 'Emergency/Error, Destructive actions',
    },
    yellow: {
        label: 'Yellow',
        shades: yellow,
        usage: 'Warning, Highlights (on dark backgrounds)',
    },
    utilities: { label: 'Disabled states', shades: utilities, usage: '' },
};

var colors = {
    grey,
    blue: blue$1,
    red,
    yellow,
    utilities,
    allColors: allColors$1,
    colorRanges,
};

// See https://css-tricks.com/snippets/css/system-font-stack/#method-1-system-fonts-at-the-element-level.
const emojiFontStack = [
    'Apple Color Emoji',
    'Segoe UI Emoji',
    'Segoe UI Symbol',
    'Noto Color Emoji',
];

// Font stack optimised for built-in fonts of each major operating system, with support for emojis.
// Only displayed if the site’s web fonts fail to load.
// See https://polaris.shopify.com/design/typography#section-font-stack.
const fallbackSans = [
    '-apple-system',
    'BlinkMacSystemFont',
    'San Francisco',
    'Segoe UI',
    'Helvetica Neue',
    'sans-serif',
    ...emojiFontStack,
];

const fallbackSerif = [
    'Roboto',
    'Georgia',
    'Cambria',
    'serif',
    ...emojiFontStack,
];

const fontSans = ['Roboto', ...fallbackSans];

const fontSerif = ['EB Garamond', ...fallbackSerif];

const fontMono = ['SFMono-Regular', 'Menlo', 'monospace'];

const fontSize = {
    h1: { lg: 56, md: 44, sm: 32 },
    h2: { lg: 32, md: 28, sm: 24 },
    h3: { lg: 24, md: 22, sm: 20 },
    h4: { lg: 20, md: 18, sm: 16 },
    h5: { lg: 16, md: 15, sm: 14 },
    h6: { lg: 16, md: 15, sm: 14 },
    body: { lg: 16, md: 15, sm: 14 },
    meta: { lg: 14, md: 13, sm: 13 },
    label: { lg: 13, md: 12, sm: 12 },
    labellight: { lg: 13, md: 12, sm: 12 },
};

const fontWeight = {
    light: 300,
    normal: 400,
    medium: 500,
    semibold: 600,
    bold: 700,
};

const letterSpacing = {
    // tightest: '-2px',
    tighter: '-0.5px',
    tight: '-0.4px',
    normal: '0',
    // wide: '0.5px',
    wider: '1px',
    // widest: '2px',
};

var typography = {
    fontSans,
    fontSerif,
    fontMono,
    fontSize,
    fontWeight,
    letterSpacing,
};

const { blue } = colors;

const borderRadius = {
    none: '0',
    DEFAULT: '3px',
    full: '100%',
};

const boxShadow = {
    // Used for Select dropdown’s elevation.
    DEFAULT: '0 1px 2px 0 rgba(184, 184, 184, 0.24)',
    // Active state for a lot of UI components.
    pressed: 'inset 1px 1px 5px 0 rgba(1, 31, 91, 0.5)',
    focus: `0 0 3px 2px ${blue.bluePastel.hex}`,
    none: 'none',
};

const spacing = {
    1: '10px',
    2: '15px',
    3: '20px',
    4: '25px',
    5: '30px',
    6: '50px',
    7: '60px',
    10: '100px',
    20: '200px',
};

var other = {
    borderRadius,
    boxShadow,
    spacing,
};

/** @typedef {{
 xs: number;
 sm: number;
 md: number;
 lg: number;
 xl: number;
}} Breakpoints */
/** @type {Breakpoints} */
const breakpoints = {
    xs: 0,
    sm: 600,
    md: 768,
    lg: 1024,
    xl: 1280,
};

var breakpoints_1 = breakpoints;

const { allColors } = colors;




var tokens = {
    colors: allColors,
    breakpoints: breakpoints_1,
    ...typography,
    ...other,
};

module.exports = tokens;
